// $Id: J4CDCDummyDriftRegion.cc,v 1.1.1.1 2001/08/31 07:38:35 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCDummyDriftRegion
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCDummyDriftRegion.hh"

//************************************************************************
//--------------------------------
// constants (detector parameters)
//--------------------------------



G4String J4CDCDummyDriftRegion::fName("DummyDriftRegion");


//************************************************************************
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCDummyDriftRegion::J4CDCDummyDriftRegion(J4VDetectorComponent *parent,
				   	     G4int nclones,
  		  	      		     G4int nbrothers, 
  		  	     		     G4int me ) : 
  		J4VCDCDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  )
{   
}


//=====================================================================
//* destructor --------------------------------------------------------

J4CDCDummyDriftRegion::~J4CDCDummyDriftRegion()
{	
//  if(fFieldWire) delete fFieldWire;
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDCDummyDriftRegion::Assemble()
{   
  if(!GetLV())
  {	  
    // define parameters
    
    G4double len  = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetZHalfLength() ;        
    G4double motherRmin = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetInnerRadius() ;       
    G4double motherRmax = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetOuterRadius() ;        
    G4double phi = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetDeltaPhiAngle() ;
        
    G4int    nbrothers  = GetNBrothers();
    G4int    myid       = GetMyID();
    G4double thick      = (motherRmax - motherRmin)/(_CDCDriftRegionNLayers_ + 2);
    G4double rmin;
    G4double rmax;
    
    if ( myid = 0 ) {
      rmin = motherRmin;
      rmax = motherRmin + thick;
    } else {
      rmin = motherRmin + thick*6;
      rmax = motherRmin + thick*7;
    }
       
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, phi );

    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_CDCDUMMYDRIFTREGIONMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV(_CDCDriftRegionVisAtt_, G4Color(0.,1.,1.));   
    

#if 0         
    // Install daughter PV //
    // Install Sense Wire  //
  
    fFieldWire = new J4CDCFieldWire(this);
    fFieldWire->InstallIn(this);
    
    SetDaughter(fFieldWire); 
#endif    
    
  }
    
}

//=====================================================================
//* Cabling   ---------------------------------------------------------

void J4CDCDummyDriftRegion::Cabling()
{	
}
//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDCDummyDriftRegion::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
    
  SetPVPlacement(0,0);
  
}

//=====================================================================
//* SwitchOn  --------------------------------------------------------
void J4CDCDummyDriftRegion::SwitchOn()
{
  SetIsOn(TRUE);
  Cabling();
}

//=====================================================================
//* SwitchOff  --------------------------------------------------------
void J4CDCDummyDriftRegion::SwitchOff()
{
  SetIsOn(FALSE);
  Cabling();
}

//=====================================================================
//* Draw  --------------------------------------------------------

void J4CDCDummyDriftRegion::Draw()
{
  // set visualization attributes
  
}
	
//=====================================================================
//* Print  --------------------------------------------------------

void J4CDCDummyDriftRegion::Print() const
{
}

	
	

