// $Id: J4CDCEndcap.cc,v 1.1.1.1 2001/08/31 07:38:35 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCEndcap
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCEndcap.hh"
#include "J4CDCParameter.hh"


// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------

G4String J4CDCEndcap::fName("Endcap");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCEndcap::J4CDCEndcap(J4VDetectorComponent *parent,
			    G4int nclones,
  		  	    G4int nbrothers, 
  		  	    G4int me ) :
  		J4VCDCDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  ) 
{   
}

//=====================================================================
//* destructor --------------------------------------------------------

J4CDCEndcap::~J4CDCEndcap()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDCEndcap::Assemble() 
{   
  if(!GetLV()){
  	
    G4double rmin = _CDCENDCAPIR_;
    G4double rmax = _CDCENDCAPOR_;
    G4double len  = _CDCENDCAPHALFTHICK_;
    G4double dphi = _CDCENDCAPDPHI_;
  	
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, dphi);
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_CDCENDCAPMATERIAL_));
        
    // SetVisAttribute ----//
    PaintLV(_CDCENDCAPVISATT_, G4Color(0, 1, 0));
  }
  	
    // Install daughter PV //
  		  
      
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4CDCEndcap::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDCEndcap::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object...
  
  G4double z = _CDCENDCAPFRONTZ_ + _CDCENDCAPHALFTHICK_;
  
  if (GetMyID() == 0) 
  {
  	G4ThreeVector tlate(0., 0., z ) ;
  	SetPVPlacement(0, tlate);
  }
  else if (GetMyID() == 1)
  {
  	G4ThreeVector tlate(0., 0., -1 * z) ;
  	SetPVPlacement(0, tlate);
  }	  	
  
}


//* SwitchOn  --------------------------------------------------------
void J4CDCEndcap::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4CDCEndcap::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4CDCEndcap::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4CDCEndcap::Print() const
{
}

	
	



