// $Id: J4PrimaryGeneratorAction.cc,v 1.2 2001/10/06 21:51:17 hoshina Exp $

#include "J4PrimaryGeneratorAction.hh"

#include <math.h>
#include "G4Event.hh"
#include "G4HEPEvtInterface.hh"
#include "G4ParticleGun.hh"
#include "G4ParticleTable.hh"
#include "G4ParticleDefinition.hh"
#include "J4PrimaryGeneratorMessenger.hh"
#include "Randomize.hh" 

J4PrimaryGeneratorAction::J4PrimaryGeneratorAction()
{
  fHEPEvt = new G4HEPEvtInterface("pythia_event.data");

  G4int n_particle = 1;
  G4ParticleGun* fParticleGun = new G4ParticleGun(n_particle);
  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
  G4String particleName;
  G4ParticleDefinition* particle
    = particleTable->FindParticle(particleName="mu+");
  fParticleGun->SetParticleDefinition(particle);
  
  G4double phi, costheta;
  G4double px, py, pz;
  G4double pabs = 10.*GeV;
 
  cerr << "J4PrimaryGeneratorAction:: G4UniformRand() = " 
       << G4UniformRand() << endl; 
       
  phi      = G4UniformRand()*M_PI*2.;
  costheta = 2*G4UniformRand() -1.;
//  costheta = 0.;
  
  G4double sintheta = sqrt((1-costheta)*(1+costheta));
  
  px = pabs * sintheta * cos(phi);
  py = pabs * sintheta * sin(phi);
  pz = pabs * costheta;
  
  fParticleGun->SetParticleMomentum(G4ThreeVector(px, py, pz));
//  fParticleGun->SetParticleEnergy(100.*GeV);
  fParticleGun->SetParticlePosition(G4ThreeVector(0.*cm,0.*cm,0.*cm));

  fMessenger = new J4PrimaryGeneratorMessenger(this);
}

J4PrimaryGeneratorAction::~J4PrimaryGeneratorAction()
{
  delete fHEPEvt;
  delete fParticleGun;
  delete fMessenger;
}

void J4PrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
{
  if(fUseHEPEvt)
  { 
  	fHEPEvt->GeneratePrimaryVertex(anEvent); 
  } else {
  	
	G4int n_particle = 1;
	G4ParticleGun* fParticleGun = new G4ParticleGun(n_particle);
	G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
	G4String particleName;
	G4ParticleDefinition* particle
	   = particleTable->FindParticle(particleName="mu+");
	fParticleGun->SetParticleDefinition(particle);
  
	G4double phi, costheta;
	G4double px, py, pz;
	G4double pabs = 350.*GeV * G4UniformRand() + 10.*MeV;
        
	phi      = G4UniformRand()*M_PI*2.;
	costheta = 2*G4UniformRand() -1.;
//	costheta = 0.;
  
	G4double sintheta = sqrt((1-costheta)*(1+costheta));
  
 	px = pabs * sintheta * cos(phi);
	py = pabs * sintheta * sin(phi);
	pz = pabs * costheta;
  
	fParticleGun->SetParticleMomentum(G4ThreeVector(px, py, pz));
	//  fParticleGun->SetParticleEnergy(100.*GeV);
	fParticleGun->SetParticlePosition(G4ThreeVector(0.*cm,0.*cm,0.*cm));
 
  	fParticleGun->GeneratePrimaryVertex(anEvent); 
  }
}




